@@ -1,5 +1,7 @@
 from numpy import ndarray
-from typing import Union, Iterable
+from typing import Union, Iterable, Sized
+
+from pandas import Series
 
 from probability.distributions.mixins.rv_continuous_1d_mixin import RVContinuous1dMixin
 from probability.distributions.mixins.rv_discrete_1d_mixin import RVDiscrete1dMixin
@@ -8,7 +10,7 @@ from probability.distributions.mixins.rv_discrete_1d_mixin import RVDiscrete1dMi
 RVMixin = Union[RVContinuous1dMixin, RVDiscrete1dMixin]
 
 Array1d = Union[Iterable[int], Iterable[float], ndarray]
-FloatArray1d = Union[Iterable[float], ndarray]
+FloatArray1d = Union[Iterable[float], ndarray, Series, Sized]
 FloatOrFloatArray1d = Union[float, Iterable[float], ndarray]
 
 Array2d = Union[Iterable[Iterable[int]], Iterable[Iterable[float]], ndarray]
