@@ -15,7 +15,8 @@ The following methods assume that the distribution is represented as follows.
 
 def margin(distribution: Series, *margins) -> Series:
     """
-    Marginalize the distribution over the variables not in args, leaving the marginal probability of args.
+    Marginalize the distribution over the variables not in args, leaving the
+    marginal probability of args.
 
     :param distribution: The probability distribution to marginalize e.g. P(A,B,C,D).
     :param margins: Names of variables to put in the margin e.g. 'C', 'D'.
@@ -43,10 +44,13 @@ comparator_symbols = {
 
 def valid_name_comparator(name_comparator: str, var_names: List[str]) -> bool:
     """
-    Return whether the given name is a valid conditioning filter name for any of the variables in var_names.
+    Return whether the given name is a valid conditioning filter name for any of
+    the variables in var_names.
 
-    :param name_comparator: Amalgamation of variable name and filtering comparator in the form '{name}__{comparator}'.
-    :param var_names: List of valid variables names to look for in `name_comparator`.
+    :param name_comparator: Amalgamation of variable name and filtering
+                            comparator in the form '{name}__{comparator}'.
+    :param var_names: List of valid variables names to look for in
+                      `name_comparator`.
     """
     for var_name in var_names:
         if name_comparator == var_name:
@@ -58,38 +62,62 @@ def valid_name_comparator(name_comparator: str, var_names: List[str]) -> bool:
     return False
 
 
-def _filter_distribution(distribution: DataFrame, name_comparator: str, value: Any) -> Tuple[DataFrame, str]:
+def _filter_distribution(
+        distribution: DataFrame,
+        name_comparator: str, value: Any
+) -> Tuple[DataFrame, str]:
     """
-    Filter probability distribution data using the variable name, comparator code and value.
+    Filter probability distribution data using the variable name, comparator
+    code and value.
 
     :param distribution: The probability distribution data to filter.
-    :param name_comparator: Amalgamation of variable name and filtering comparator in the form '{name}__{comparator}'.
+    :param name_comparator: Amalgamation of variable name and filtering
+                            comparator in the form '{name}__{comparator}'.
     :param value: Value to filter to.
     :return: Filtered Data, Variable Name
     """
     var_names = [col for col in distribution if col != 'p']
 
     def match_var(code: str) -> bool:
-        return name_comparator in [f'{var_name}__{code}' for var_name in var_names]
+        return name_comparator in [f'{var_name}__{code}'
+                                   for var_name in var_names]
 
     if name_comparator in var_names:
-        return distribution.loc[distribution[name_comparator] == value], name_comparator
+        return distribution.loc[
+            distribution[name_comparator] == value
+        ], name_comparator
     elif match_var('eq'):
-        return distribution.loc[distribution[name_comparator[: -4]] == value], name_comparator[: -4]
+        return distribution.loc[
+            distribution[name_comparator[: -4]] == value
+        ], name_comparator[: -4]
     elif match_var('ne'):
-        return distribution.loc[distribution[name_comparator[: -4]] != value], name_comparator[: -4]
+        return distribution.loc[
+            distribution[name_comparator[: -4]] != value
+        ], name_comparator[: -4]
     elif match_var('lt'):
-        return distribution.loc[distribution[name_comparator[: -4]] < value], name_comparator[: -4]
+        return distribution.loc[
+            distribution[name_comparator[: -4]] < value
+        ], name_comparator[: -4]
     elif match_var('gt'):
-        return distribution.loc[distribution[name_comparator[: -4]] > value], name_comparator[: -4]
+        return distribution.loc[
+            distribution[name_comparator[: -4]] > value
+        ], name_comparator[: -4]
     elif match_var('le'):
-        return distribution.loc[distribution[name_comparator[: -4]] <= value], name_comparator[: -4]
+        return distribution.loc[
+            distribution[name_comparator[: -4]] <= value
+        ], name_comparator[: -4]
     elif match_var('ge'):
-        return distribution.loc[distribution[name_comparator[: -4]] >= value], name_comparator[: -4]
+        return distribution.loc[
+            distribution[name_comparator[: -4]] >= value
+        ], name_comparator[: -4]
     elif match_var('in'):
-        return distribution.loc[distribution[name_comparator[: -4]].isin(value)], name_comparator[: -4]
+        return distribution.loc[
+            distribution[name_comparator[: -4]].isin(value)
+    ], name_comparator[: -4]
     elif match_var('not_in'):
-        return distribution.loc[~distribution[name_comparator[: -8]].isin(value)], name_comparator[: -8]
+        return distribution.loc[
+            ~distribution[name_comparator[: -8]].isin(value)
+    ], name_comparator[: -8]
 
 
 def cond_name(name_comparator: str, var_names: List[str] = None) -> str:
