@@ -14,7 +14,9 @@ class PriorMixin(object):
     _label: str
     _str_params: str
 
-    def plot(self, x: ndarray, color: str = 'C1', ax: Optional[Axes] = None) -> Axes:
+    def plot(self, x: ndarray, color: str = 'C1',
+             ax: Optional[Axes] = None,
+             **kwargs) -> Axes:
         """
         Plot the prior probability of the parameter θ given the priors α, β
 
@@ -23,12 +25,13 @@ class PriorMixin(object):
         :param x: vector of possible `x`s
         :param color: Optional color for the series.
         :param ax: Optional matplotlib axes
-        :rtype: Axes
+        :param kwargs: Additional arguments to pass to plot method.
         """
         ax = ax or new_axes()
         self._distribution.pdf().at(x).plot(
             kind='line', label=self._label,
-            color=color or 'C0', ax=ax
+            color=color or 'C0', ax=ax,
+            **kwargs
         )
         ax.set_xlabel(self._x_label)
         ax.set_ylabel(self._y_label)
