@@ -2,16 +2,20 @@ from matplotlib.axes import Axes
 from scipy.stats import rv_discrete
 from typing import Iterable, Optional
 
-from probability.distributions.mixins.plottable_mixin import PlottableMixin
-from probability.distributions.mixins.rv_mixins import RVS1dMixin, EntropyMixin, Median1dMixin, Mean1dMixin, \
-    StD1dMixin, Var1dMixin, Interval1dMixin, PMF1dMixin, CDFDiscrete1dMixin, SFDiscrete1dMixin, PPFDiscrete1dMixin, \
-    ISFDiscrete1dMixin
+from probability.distributions.mixins.plottable_mixin import \
+    DiscretePlottableMixin
+from probability.distributions.mixins.rv_mixins import RVS1dMixin, \
+    EntropyMixin, Median1dMixin, Mean1dMixin, StD1dMixin, Var1dMixin, \
+    Interval1dMixin, PMF1dMixin, CDFDiscrete1dMixin, SFDiscrete1dMixin, \
+    PPFDiscrete1dMixin, ISFDiscrete1dMixin
 
 
 class RVDiscrete1dMixin(
-    RVS1dMixin, EntropyMixin, Median1dMixin, Mean1dMixin, StD1dMixin, Var1dMixin, Interval1dMixin,
-    PMF1dMixin, CDFDiscrete1dMixin, SFDiscrete1dMixin, PPFDiscrete1dMixin, ISFDiscrete1dMixin,
-    PlottableMixin, object
+    RVS1dMixin, EntropyMixin, Median1dMixin, Mean1dMixin, StD1dMixin,
+    Var1dMixin, Interval1dMixin, PMF1dMixin, CDFDiscrete1dMixin,
+    SFDiscrete1dMixin, PPFDiscrete1dMixin, ISFDiscrete1dMixin,
+    DiscretePlottableMixin,
+    object
 ):
 
     _distribution: rv_discrete
